@@ -7,11 +7,10 @@ import requests
 
 
 class MayaBaseRequest(ABC):
-
     def __init__(self, *args, **kwargs):
         self.request = requests.Request(self.method, **kwargs)
-        self.request.headers['Cache-Control'] = 'no-cache'
-        self.request.headers['User-Agent'] = UserAgent(verify_ssl=False).chrome
+        self.request.headers["Cache-Control"] = "no-cache"
+        self.request.headers["User-Agent"] = UserAgent(verify_ssl=False).chrome
 
     @property
     @abstractmethod
